.TH "dmt" 2 " June 6th 1997" "Fractales Group" "Scilab Function"

.SH NAME
dmt - Discrete Mellin transform of a vector
.sp
Author: Paulo Goncalves
.sp
Computes the Fast Mellin transform of a signal.
.sp
.sp
.SH Usage
.nf
[mellin,beta] = dmt(s,[fmin,fmax,N]) 
.fi
.SH Input parameters


.RS

.TP
o 
\fBs\fP : real vector [1,nt] or [nt,1]
Time samples of the signal to be transformed. 

.TP
o 
\fBfmin\fP : real scalar in [0,0.5]
Lower frequency bound of the signal

.TP
o 
\fBfmax\fP :  real scalar [0,0.5] and \fIfmax\fP >\fP 
Upper frequency bound of the  signal

.TP
o 
\fBN\fP : positive integer. 
number of Mellin samples.
.RE

.SH Output parameters


.RS

.TP
o 
\fBmellin\fP : complex vector [1,N]
Mellin transform of \fIs\fP.

.TP
o 
\fBbeta\fP : real vector [1,N]
Variable of the Mellin transform \fImellin\fP.
.RE

.SH Description
.SH Parameters


.RS

.TP
o 
\fIs\fP : signal to be transformed. Real or complex vector. 

.TP
o 
\fIfmin\fP : lower frequency bound of the analysis. \fIfmin\fP is
real scalar comprised in  [0,0.5]

.TP
o 
\fIfmax\fP : upper frequency bound of the analysis. \fIfmax\fP is
a real scalar comprised in [0,0.5] and \fIfmax\fP >\fP
\fIfmin\fP

.TP
o 
\fIN\fP : number of Mellin samples. This number must be greater
than some ammount determined by the spectral extent of the signal, to
avoid aliasing in the Mellin domain.
.RE

.SH Algorithm details
The fast Mellin transform can be simply interpreted as a FFT applied
to a geometrically sampled vector. 
.SH See also:
idmt, dilate
.SH Example:
.nf
//Signal synthesis
x = morlet(0.1,32) ;
plot(x)
//Computation of the Mellin transform
[mellin,beta] = dmt(x,0.01,0.5,128) ;
plot(beta,abs(mellin))
.fi 

